=============
API Reference
=============

CLARITE functions are organized into several modules:

.. automodule:: clarite.analyze

-----

.. automodule:: clarite.describe

-----

.. automodule:: clarite.io

-----

.. automodule:: clarite.modify

-----

.. automodule:: clarite.plot

-----

.. automodule:: clarite.process

-----

.. automodule:: clarite.survey
